@@ -14,7 +14,7 @@
 *****************************************************************************/
 
 static const unsigned char qt_resource_data[] = {
-  // /cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.i686/src/octave-4.4.1/libgui/graphics/images/zoom-in.png
+  // /cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/images/zoom-in.png
   0x0,0x0,0xc,0xed,
   0x89,
   0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
@@ -224,7 +224,7 @@ static const unsigned char qt_resource_data[] = {
   0x36,0x4a,0x52,0xa8,0x54,0xa9,0x24,0x6e,0xdf,0xba,0x99,0x63,0x8d,0xe7,0xfc,0xbf,
   0x62,0x8c,0x69,0x56,0x77,0x48,0xfd,0x5,0x6f,0xa7,0x92,0xe,0xce,0xcc,0xa4,0x14,
   0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
-    // /cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.i686/src/octave-4.4.1/libgui/graphics/images/select.png
+    // /cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/images/select.png
   0x0,0x0,0xc,0x83,
   0x89,
   0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
@@ -428,7 +428,7 @@ static const unsigned char qt_resource_data[] = {
   0xb6,0x6a,0x46,0xbf,0xf1,0x7,0xf0,0xd,0xf8,0x13,0x73,0x7f,0x7,0x0,0x13,0xf2,
   0x2d,0xeb,0x99,0xc8,0x6,0x7a,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,
   0x60,0x82,
-    // /cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.i686/src/octave-4.4.1/libgui/graphics/images/rotate.png
+    // /cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/images/rotate.png
   0x0,0x0,0xe,0x35,
   0x89,
   0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
@@ -659,7 +659,7 @@ static const unsigned char qt_resource_data[] = {
   0x66,0x8e,0xe3,0xf4,0x85,0x10,0x7f,0x11,0xd1,0xe5,0x2b,0x18,0x0,0xfe,0x1b,0x0,
   0xc2,0x4,0xbc,0x80,0x35,0x56,0x18,0x55,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,
   0xae,0x42,0x60,0x82,
-    // /cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.i686/src/octave-4.4.1/libgui/graphics/images/zoom-out.png
+    // /cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/images/zoom-out.png
   0x0,0x0,0xc,0xe5,
   0x89,
   0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
@@ -869,7 +869,7 @@ static const unsigned char qt_resource_data[] = {
   0xdc,0xbf,0x37,0x27,0xd6,0x9e,0xf3,0xff,0x4a,0x8,0x61,0x58,0xf9,0x43,0xfa,0x6f,
   0xed,0x12,0x8d,0xfb,0x74,0xe7,0xd6,0x73,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,
   0xae,0x42,0x60,0x82,
-    // /cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.i686/src/octave-4.4.1/libgui/graphics/images/pan.png
+    // /cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/graphics/images/pan.png
   0x0,0x0,0xb,0x42,
   0x89,
   0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
@@ -1099,19 +1099,19 @@ static const unsigned char qt_resource_struct[] = {
 0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
   // :/images/zoom-in.png
   0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
-0x0,0x0,0x1,0x65,0x1f,0xeb,0x31,0x80,
+0x0,0x0,0x1,0x69,0x1b,0x6b,0x65,0x68,
   // :/images/pan.png
   0x0,0x0,0x0,0x80,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x34,0x9a,
-0x0,0x0,0x1,0x65,0x1f,0xeb,0x31,0x80,
+0x0,0x0,0x1,0x69,0x1b,0x6b,0x65,0x68,
   // :/images/zoom-out.png
   0x0,0x0,0x0,0x62,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x27,0xb1,
-0x0,0x0,0x1,0x65,0x1f,0xeb,0x31,0x80,
+0x0,0x0,0x1,0x69,0x1b,0x6b,0x65,0x68,
   // :/images/rotate.png
   0x0,0x0,0x0,0x48,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x19,0x78,
-0x0,0x0,0x1,0x65,0x1f,0xeb,0x31,0x80,
+0x0,0x0,0x1,0x69,0x1b,0x6b,0x65,0x68,
   // :/images/select.png
   0x0,0x0,0x0,0x2e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0xc,0xf1,
-0x0,0x0,0x1,0x65,0x1f,0xeb,0x31,0x80,
+0x0,0x0,0x1,0x69,0x1b,0x6b,0x65,0x68,
 
 };
 
