@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.x86_64/src/octave-4.4.1/libgui/src/files-dock-widget.h"
+#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/files-dock-widget.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__files_dock_widget_t {
-    QByteArrayData data[53];
-    char stringdata0[901];
+    QByteArrayData data[54];
+    char stringdata0[917];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -41,61 +41,63 @@ QT_MOC_LITERAL(3, 37, 8), // "fileName"
 QT_MOC_LITERAL(4, 46, 27), // "displayed_directory_changed"
 QT_MOC_LITERAL(5, 74, 3), // "dir"
 QT_MOC_LITERAL(6, 78, 16), // "load_file_signal"
-QT_MOC_LITERAL(7, 95, 15), // "run_file_signal"
-QT_MOC_LITERAL(8, 111, 9), // "QFileInfo"
-QT_MOC_LITERAL(9, 121, 4), // "info"
-QT_MOC_LITERAL(10, 126, 17), // "find_files_signal"
-QT_MOC_LITERAL(11, 144, 8), // "startdir"
-QT_MOC_LITERAL(12, 153, 18), // "file_remove_signal"
-QT_MOC_LITERAL(13, 172, 8), // "old_name"
-QT_MOC_LITERAL(14, 181, 8), // "new_name"
-QT_MOC_LITERAL(15, 190, 19), // "file_renamed_signal"
-QT_MOC_LITERAL(16, 210, 19), // "item_double_clicked"
-QT_MOC_LITERAL(17, 230, 5), // "index"
-QT_MOC_LITERAL(18, 236, 19), // "change_directory_up"
-QT_MOC_LITERAL(19, 256, 24), // "do_sync_octave_directory"
-QT_MOC_LITERAL(20, 281, 25), // "do_sync_browser_directory"
-QT_MOC_LITERAL(21, 307, 21), // "set_current_directory"
-QT_MOC_LITERAL(22, 329, 26), // "accept_directory_line_edit"
-QT_MOC_LITERAL(23, 356, 23), // "update_octave_directory"
-QT_MOC_LITERAL(24, 380, 15), // "notice_settings"
-QT_MOC_LITERAL(25, 396, 16), // "const QSettings*"
-QT_MOC_LITERAL(26, 413, 8), // "settings"
-QT_MOC_LITERAL(27, 422, 13), // "save_settings"
-QT_MOC_LITERAL(28, 436, 27), // "headercontextmenu_requested"
-QT_MOC_LITERAL(29, 464, 3), // "pos"
-QT_MOC_LITERAL(30, 468, 13), // "toggle_header"
-QT_MOC_LITERAL(31, 482, 3), // "col"
-QT_MOC_LITERAL(32, 486, 21), // "contextmenu_requested"
-QT_MOC_LITERAL(33, 508, 16), // "contextmenu_open"
-QT_MOC_LITERAL(34, 525, 26), // "contextmenu_open_in_editor"
-QT_MOC_LITERAL(35, 552, 23), // "contextmenu_open_in_app"
-QT_MOC_LITERAL(36, 576, 26), // "contextmenu_copy_selection"
-QT_MOC_LITERAL(37, 603, 15), // "contextmenu_run"
-QT_MOC_LITERAL(38, 619, 16), // "contextmenu_load"
-QT_MOC_LITERAL(39, 636, 18), // "contextmenu_rename"
-QT_MOC_LITERAL(40, 655, 18), // "contextmenu_delete"
-QT_MOC_LITERAL(41, 674, 19), // "contextmenu_newfile"
-QT_MOC_LITERAL(42, 694, 18), // "contextmenu_newdir"
-QT_MOC_LITERAL(43, 713, 25), // "contextmenu_setcurrentdir"
-QT_MOC_LITERAL(44, 739, 21), // "contextmenu_findfiles"
-QT_MOC_LITERAL(45, 761, 19), // "popdownmenu_newfile"
-QT_MOC_LITERAL(46, 781, 18), // "popdownmenu_newdir"
-QT_MOC_LITERAL(47, 800, 22), // "popdownmenu_search_dir"
-QT_MOC_LITERAL(48, 823, 21), // "popdownmenu_findfiles"
-QT_MOC_LITERAL(49, 845, 16), // "popdownmenu_home"
-QT_MOC_LITERAL(50, 862, 13), // "copyClipboard"
-QT_MOC_LITERAL(51, 876, 14), // "pasteClipboard"
-QT_MOC_LITERAL(52, 891, 9) // "selectAll"
+QT_MOC_LITERAL(7, 95, 15), // "open_any_signal"
+QT_MOC_LITERAL(8, 111, 15), // "run_file_signal"
+QT_MOC_LITERAL(9, 127, 9), // "QFileInfo"
+QT_MOC_LITERAL(10, 137, 4), // "info"
+QT_MOC_LITERAL(11, 142, 17), // "find_files_signal"
+QT_MOC_LITERAL(12, 160, 8), // "startdir"
+QT_MOC_LITERAL(13, 169, 18), // "file_remove_signal"
+QT_MOC_LITERAL(14, 188, 8), // "old_name"
+QT_MOC_LITERAL(15, 197, 8), // "new_name"
+QT_MOC_LITERAL(16, 206, 19), // "file_renamed_signal"
+QT_MOC_LITERAL(17, 226, 19), // "item_double_clicked"
+QT_MOC_LITERAL(18, 246, 5), // "index"
+QT_MOC_LITERAL(19, 252, 19), // "change_directory_up"
+QT_MOC_LITERAL(20, 272, 24), // "do_sync_octave_directory"
+QT_MOC_LITERAL(21, 297, 25), // "do_sync_browser_directory"
+QT_MOC_LITERAL(22, 323, 21), // "set_current_directory"
+QT_MOC_LITERAL(23, 345, 26), // "accept_directory_line_edit"
+QT_MOC_LITERAL(24, 372, 23), // "update_octave_directory"
+QT_MOC_LITERAL(25, 396, 15), // "notice_settings"
+QT_MOC_LITERAL(26, 412, 16), // "const QSettings*"
+QT_MOC_LITERAL(27, 429, 8), // "settings"
+QT_MOC_LITERAL(28, 438, 13), // "save_settings"
+QT_MOC_LITERAL(29, 452, 27), // "headercontextmenu_requested"
+QT_MOC_LITERAL(30, 480, 3), // "pos"
+QT_MOC_LITERAL(31, 484, 13), // "toggle_header"
+QT_MOC_LITERAL(32, 498, 3), // "col"
+QT_MOC_LITERAL(33, 502, 21), // "contextmenu_requested"
+QT_MOC_LITERAL(34, 524, 16), // "contextmenu_open"
+QT_MOC_LITERAL(35, 541, 26), // "contextmenu_open_in_editor"
+QT_MOC_LITERAL(36, 568, 23), // "contextmenu_open_in_app"
+QT_MOC_LITERAL(37, 592, 26), // "contextmenu_copy_selection"
+QT_MOC_LITERAL(38, 619, 15), // "contextmenu_run"
+QT_MOC_LITERAL(39, 635, 16), // "contextmenu_load"
+QT_MOC_LITERAL(40, 652, 18), // "contextmenu_rename"
+QT_MOC_LITERAL(41, 671, 18), // "contextmenu_delete"
+QT_MOC_LITERAL(42, 690, 19), // "contextmenu_newfile"
+QT_MOC_LITERAL(43, 710, 18), // "contextmenu_newdir"
+QT_MOC_LITERAL(44, 729, 25), // "contextmenu_setcurrentdir"
+QT_MOC_LITERAL(45, 755, 21), // "contextmenu_findfiles"
+QT_MOC_LITERAL(46, 777, 19), // "popdownmenu_newfile"
+QT_MOC_LITERAL(47, 797, 18), // "popdownmenu_newdir"
+QT_MOC_LITERAL(48, 816, 22), // "popdownmenu_search_dir"
+QT_MOC_LITERAL(49, 839, 21), // "popdownmenu_findfiles"
+QT_MOC_LITERAL(50, 861, 16), // "popdownmenu_home"
+QT_MOC_LITERAL(51, 878, 13), // "copyClipboard"
+QT_MOC_LITERAL(52, 892, 14), // "pasteClipboard"
+QT_MOC_LITERAL(53, 907, 9) // "selectAll"
 
     },
     "octave::files_dock_widget\0open_file\0"
     "\0fileName\0displayed_directory_changed\0"
-    "dir\0load_file_signal\0run_file_signal\0"
-    "QFileInfo\0info\0find_files_signal\0"
-    "startdir\0file_remove_signal\0old_name\0"
-    "new_name\0file_renamed_signal\0"
-    "item_double_clicked\0index\0change_directory_up\0"
+    "dir\0load_file_signal\0open_any_signal\0"
+    "run_file_signal\0QFileInfo\0info\0"
+    "find_files_signal\0startdir\0"
+    "file_remove_signal\0old_name\0new_name\0"
+    "file_renamed_signal\0item_double_clicked\0"
+    "index\0change_directory_up\0"
     "do_sync_octave_directory\0"
     "do_sync_browser_directory\0"
     "set_current_directory\0accept_directory_line_edit\0"
@@ -122,78 +124,80 @@ static const uint qt_meta_data_octave__files_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      39,   14, // methods
+      40,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       7,       // signalCount
+       8,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  209,    2, 0x06 /* Public */,
-       4,    1,  212,    2, 0x06 /* Public */,
-       6,    1,  215,    2, 0x06 /* Public */,
-       7,    1,  218,    2, 0x06 /* Public */,
-      10,    1,  221,    2, 0x06 /* Public */,
-      12,    2,  224,    2, 0x06 /* Public */,
-      15,    1,  229,    2, 0x06 /* Public */,
+       1,    1,  214,    2, 0x06 /* Public */,
+       4,    1,  217,    2, 0x06 /* Public */,
+       6,    1,  220,    2, 0x06 /* Public */,
+       7,    1,  223,    2, 0x06 /* Public */,
+       8,    1,  226,    2, 0x06 /* Public */,
+      11,    1,  229,    2, 0x06 /* Public */,
+      13,    2,  232,    2, 0x06 /* Public */,
+      16,    1,  237,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      16,    1,  232,    2, 0x0a /* Public */,
-      18,    0,  235,    2, 0x0a /* Public */,
-      19,    0,  236,    2, 0x0a /* Public */,
-      20,    0,  237,    2, 0x0a /* Public */,
-      21,    1,  238,    2, 0x0a /* Public */,
-      22,    0,  241,    2, 0x0a /* Public */,
-      23,    1,  242,    2, 0x0a /* Public */,
-      24,    1,  245,    2, 0x0a /* Public */,
-      27,    0,  248,    2, 0x0a /* Public */,
-      28,    1,  249,    2, 0x08 /* Private */,
-      30,    1,  252,    2, 0x08 /* Private */,
-      32,    1,  255,    2, 0x08 /* Private */,
-      33,    1,  258,    2, 0x08 /* Private */,
-      34,    1,  261,    2, 0x08 /* Private */,
-      35,    1,  264,    2, 0x08 /* Private */,
-      36,    1,  267,    2, 0x08 /* Private */,
-      37,    1,  270,    2, 0x08 /* Private */,
-      38,    1,  273,    2, 0x08 /* Private */,
-      39,    1,  276,    2, 0x08 /* Private */,
-      40,    1,  279,    2, 0x08 /* Private */,
-      41,    1,  282,    2, 0x08 /* Private */,
-      42,    1,  285,    2, 0x08 /* Private */,
-      43,    1,  288,    2, 0x08 /* Private */,
-      44,    1,  291,    2, 0x08 /* Private */,
-      45,    1,  294,    2, 0x08 /* Private */,
-      46,    1,  297,    2, 0x08 /* Private */,
-      47,    1,  300,    2, 0x08 /* Private */,
-      48,    1,  303,    2, 0x08 /* Private */,
-      49,    1,  306,    2, 0x08 /* Private */,
-      50,    0,  309,    2, 0x08 /* Private */,
-      51,    0,  310,    2, 0x08 /* Private */,
-      52,    0,  311,    2, 0x08 /* Private */,
+      17,    1,  240,    2, 0x0a /* Public */,
+      19,    0,  243,    2, 0x0a /* Public */,
+      20,    0,  244,    2, 0x0a /* Public */,
+      21,    0,  245,    2, 0x0a /* Public */,
+      22,    1,  246,    2, 0x0a /* Public */,
+      23,    0,  249,    2, 0x0a /* Public */,
+      24,    1,  250,    2, 0x0a /* Public */,
+      25,    1,  253,    2, 0x0a /* Public */,
+      28,    0,  256,    2, 0x0a /* Public */,
+      29,    1,  257,    2, 0x08 /* Private */,
+      31,    1,  260,    2, 0x08 /* Private */,
+      33,    1,  263,    2, 0x08 /* Private */,
+      34,    1,  266,    2, 0x08 /* Private */,
+      35,    1,  269,    2, 0x08 /* Private */,
+      36,    1,  272,    2, 0x08 /* Private */,
+      37,    1,  275,    2, 0x08 /* Private */,
+      38,    1,  278,    2, 0x08 /* Private */,
+      39,    1,  281,    2, 0x08 /* Private */,
+      40,    1,  284,    2, 0x08 /* Private */,
+      41,    1,  287,    2, 0x08 /* Private */,
+      42,    1,  290,    2, 0x08 /* Private */,
+      43,    1,  293,    2, 0x08 /* Private */,
+      44,    1,  296,    2, 0x08 /* Private */,
+      45,    1,  299,    2, 0x08 /* Private */,
+      46,    1,  302,    2, 0x08 /* Private */,
+      47,    1,  305,    2, 0x08 /* Private */,
+      48,    1,  308,    2, 0x08 /* Private */,
+      49,    1,  311,    2, 0x08 /* Private */,
+      50,    1,  314,    2, 0x08 /* Private */,
+      51,    0,  317,    2, 0x08 /* Private */,
+      52,    0,  318,    2, 0x08 /* Private */,
+      53,    0,  319,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
     QMetaType::Void, QMetaType::QString,    5,
     QMetaType::Void, QMetaType::QString,    3,
-    QMetaType::Void, 0x80000000 | 8,    9,
-    QMetaType::Void, QMetaType::QString,   11,
-    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
+    QMetaType::Void, QMetaType::QString,    3,
+    QMetaType::Void, 0x80000000 | 9,   10,
+    QMetaType::Void, QMetaType::QString,   12,
+    QMetaType::Void, QMetaType::QString, QMetaType::QString,   14,   15,
     QMetaType::Void, QMetaType::Bool,    2,
 
  // slots: parameters
-    QMetaType::Void, QMetaType::QModelIndex,   17,
+    QMetaType::Void, QMetaType::QModelIndex,   18,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString,    5,
     QMetaType::Void,
     QMetaType::Void, QMetaType::QString,    5,
-    QMetaType::Void, 0x80000000 | 25,   26,
+    QMetaType::Void, 0x80000000 | 26,   27,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QPoint,   29,
-    QMetaType::Void, QMetaType::Int,   31,
-    QMetaType::Void, QMetaType::QPoint,   29,
+    QMetaType::Void, QMetaType::QPoint,   30,
+    QMetaType::Void, QMetaType::Int,   32,
+    QMetaType::Void, QMetaType::QPoint,   30,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
@@ -227,42 +231,43 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
         case 0: _t->open_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 1: _t->displayed_directory_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 2: _t->load_file_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 3: _t->run_file_signal((*reinterpret_cast< const QFileInfo(*)>(_a[1]))); break;
-        case 4: _t->find_files_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 5: _t->file_remove_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
-        case 6: _t->file_renamed_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 7: _t->item_double_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
-        case 8: _t->change_directory_up(); break;
-        case 9: _t->do_sync_octave_directory(); break;
-        case 10: _t->do_sync_browser_directory(); break;
-        case 11: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 12: _t->accept_directory_line_edit(); break;
-        case 13: _t->update_octave_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 14: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 15: _t->save_settings(); break;
-        case 16: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 17: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 18: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 19: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 20: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 21: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 22: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 23: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 24: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 25: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 26: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 27: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 28: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 29: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 30: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 31: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 32: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 33: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 34: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 35: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 36: _t->copyClipboard(); break;
-        case 37: _t->pasteClipboard(); break;
-        case 38: _t->selectAll(); break;
+        case 3: _t->open_any_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 4: _t->run_file_signal((*reinterpret_cast< const QFileInfo(*)>(_a[1]))); break;
+        case 5: _t->find_files_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 6: _t->file_remove_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
+        case 7: _t->file_renamed_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 8: _t->item_double_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
+        case 9: _t->change_directory_up(); break;
+        case 10: _t->do_sync_octave_directory(); break;
+        case 11: _t->do_sync_browser_directory(); break;
+        case 12: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 13: _t->accept_directory_line_edit(); break;
+        case 14: _t->update_octave_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 15: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
+        case 16: _t->save_settings(); break;
+        case 17: _t->headercontextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 18: _t->toggle_header((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 19: _t->contextmenu_requested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 20: _t->contextmenu_open((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 21: _t->contextmenu_open_in_editor((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 22: _t->contextmenu_open_in_app((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 23: _t->contextmenu_copy_selection((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 24: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 25: _t->contextmenu_load((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 26: _t->contextmenu_rename((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 27: _t->contextmenu_delete((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 28: _t->contextmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 29: _t->contextmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 30: _t->contextmenu_setcurrentdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 31: _t->contextmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 32: _t->popdownmenu_newfile((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 33: _t->popdownmenu_newdir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 34: _t->popdownmenu_search_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 35: _t->popdownmenu_findfiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 36: _t->popdownmenu_home((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 37: _t->copyClipboard(); break;
+        case 38: _t->pasteClipboard(); break;
+        case 39: _t->selectAll(); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -288,31 +293,38 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
                 return;
             }
         }
+        {
+            typedef void (files_dock_widget::*_t)(const QString & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::open_any_signal)) {
+                *result = 3;
+                return;
+            }
+        }
         {
             typedef void (files_dock_widget::*_t)(const QFileInfo & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::run_file_signal)) {
-                *result = 3;
+                *result = 4;
                 return;
             }
         }
         {
             typedef void (files_dock_widget::*_t)(const QString & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::find_files_signal)) {
-                *result = 4;
+                *result = 5;
                 return;
             }
         }
         {
             typedef void (files_dock_widget::*_t)(const QString & , const QString & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::file_remove_signal)) {
-                *result = 5;
+                *result = 6;
                 return;
             }
         }
         {
             typedef void (files_dock_widget::*_t)(bool );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&files_dock_widget::file_renamed_signal)) {
-                *result = 6;
+                *result = 7;
                 return;
             }
         }
@@ -344,13 +356,13 @@ int octave::files_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void *
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 39)
+        if (_id < 40)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 39;
+        _id -= 40;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 39)
+        if (_id < 40)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 39;
+        _id -= 40;
     }
     return _id;
 }
@@ -377,31 +389,38 @@ void octave::files_dock_widget::load_file_signal(const QString & _t1)
 }
 
 // SIGNAL 3
-void octave::files_dock_widget::run_file_signal(const QFileInfo & _t1)
+void octave::files_dock_widget::open_any_signal(const QString & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 3, _a);
 }
 
 // SIGNAL 4
-void octave::files_dock_widget::find_files_signal(const QString & _t1)
+void octave::files_dock_widget::run_file_signal(const QFileInfo & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 4, _a);
 }
 
 // SIGNAL 5
-void octave::files_dock_widget::file_remove_signal(const QString & _t1, const QString & _t2)
+void octave::files_dock_widget::find_files_signal(const QString & _t1)
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 5, _a);
 }
 
 // SIGNAL 6
+void octave::files_dock_widget::file_remove_signal(const QString & _t1, const QString & _t2)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
+    QMetaObject::activate(this, &staticMetaObject, 6, _a);
+}
+
+// SIGNAL 7
 void octave::files_dock_widget::file_renamed_signal(bool _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
-    QMetaObject::activate(this, &staticMetaObject, 6, _a);
+    QMetaObject::activate(this, &staticMetaObject, 7, _a);
 }
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
