@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.x86_64/src/octave-4.4.1/libgui/src/settings-dialog.h"
+#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/settings-dialog.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -23,36 +23,36 @@
 QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
-struct qt_meta_stringdata_settings_dialog_t {
+struct qt_meta_stringdata_octave__settings_dialog_t {
     QByteArrayData data[15];
-    char stringdata0[234];
+    char stringdata0[242];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
-    qptrdiff(offsetof(qt_meta_stringdata_settings_dialog_t, stringdata0) + ofs \
+    qptrdiff(offsetof(qt_meta_stringdata_octave__settings_dialog_t, stringdata0) + ofs \
         - idx * sizeof(QByteArrayData)) \
     )
-static const qt_meta_stringdata_settings_dialog_t qt_meta_stringdata_settings_dialog = {
+static const qt_meta_stringdata_octave__settings_dialog_t qt_meta_stringdata_octave__settings_dialog = {
     {
-QT_MOC_LITERAL(0, 0, 15), // "settings_dialog"
-QT_MOC_LITERAL(1, 16, 18), // "apply_new_settings"
-QT_MOC_LITERAL(2, 35, 0), // ""
-QT_MOC_LITERAL(3, 36, 14), // "get_octave_dir"
-QT_MOC_LITERAL(4, 51, 20), // "get_file_browser_dir"
-QT_MOC_LITERAL(5, 72, 7), // "get_dir"
-QT_MOC_LITERAL(6, 80, 10), // "QLineEdit*"
-QT_MOC_LITERAL(7, 91, 34), // "set_disabled_pref_file_browse..."
-QT_MOC_LITERAL(8, 126, 7), // "disable"
-QT_MOC_LITERAL(9, 134, 14), // "button_clicked"
-QT_MOC_LITERAL(10, 149, 16), // "QAbstractButton*"
-QT_MOC_LITERAL(11, 166, 6), // "button"
-QT_MOC_LITERAL(12, 173, 19), // "import_shortcut_set"
-QT_MOC_LITERAL(13, 193, 19), // "export_shortcut_set"
-QT_MOC_LITERAL(14, 213, 20) // "default_shortcut_set"
+QT_MOC_LITERAL(0, 0, 23), // "octave::settings_dialog"
+QT_MOC_LITERAL(1, 24, 18), // "apply_new_settings"
+QT_MOC_LITERAL(2, 43, 0), // ""
+QT_MOC_LITERAL(3, 44, 14), // "get_octave_dir"
+QT_MOC_LITERAL(4, 59, 20), // "get_file_browser_dir"
+QT_MOC_LITERAL(5, 80, 7), // "get_dir"
+QT_MOC_LITERAL(6, 88, 10), // "QLineEdit*"
+QT_MOC_LITERAL(7, 99, 34), // "set_disabled_pref_file_browse..."
+QT_MOC_LITERAL(8, 134, 7), // "disable"
+QT_MOC_LITERAL(9, 142, 14), // "button_clicked"
+QT_MOC_LITERAL(10, 157, 16), // "QAbstractButton*"
+QT_MOC_LITERAL(11, 174, 6), // "button"
+QT_MOC_LITERAL(12, 181, 19), // "import_shortcut_set"
+QT_MOC_LITERAL(13, 201, 19), // "export_shortcut_set"
+QT_MOC_LITERAL(14, 221, 20) // "default_shortcut_set"
 
     },
-    "settings_dialog\0apply_new_settings\0\0"
-    "get_octave_dir\0get_file_browser_dir\0"
+    "octave::settings_dialog\0apply_new_settings\0"
+    "\0get_octave_dir\0get_file_browser_dir\0"
     "get_dir\0QLineEdit*\0"
     "set_disabled_pref_file_browser_dir\0"
     "disable\0button_clicked\0QAbstractButton*\0"
@@ -61,7 +61,7 @@ QT_MOC_LITERAL(14, 213, 20) // "default_shortcut_set"
 };
 #undef QT_MOC_LITERAL
 
-static const uint qt_meta_data_settings_dialog[] = {
+static const uint qt_meta_data_octave__settings_dialog[] = {
 
  // content:
        7,       // revision
@@ -103,7 +103,7 @@ static const uint qt_meta_data_settings_dialog[] = {
        0        // eod
 };
 
-void settings_dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+void octave::settings_dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
         settings_dialog *_t = static_cast<settings_dialog *>(_o);
@@ -132,26 +132,26 @@ void settings_dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int
     }
 }
 
-const QMetaObject settings_dialog::staticMetaObject = {
-    { &QDialog::staticMetaObject, qt_meta_stringdata_settings_dialog.data,
-      qt_meta_data_settings_dialog,  qt_static_metacall, nullptr, nullptr}
+const QMetaObject octave::settings_dialog::staticMetaObject = {
+    { &QDialog::staticMetaObject, qt_meta_stringdata_octave__settings_dialog.data,
+      qt_meta_data_octave__settings_dialog,  qt_static_metacall, nullptr, nullptr}
 };
 
 
-const QMetaObject *settings_dialog::metaObject() const
+const QMetaObject *octave::settings_dialog::metaObject() const
 {
     return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
-void *settings_dialog::qt_metacast(const char *_clname)
+void *octave::settings_dialog::qt_metacast(const char *_clname)
 {
     if (!_clname) return nullptr;
-    if (!strcmp(_clname, qt_meta_stringdata_settings_dialog.stringdata0))
+    if (!strcmp(_clname, qt_meta_stringdata_octave__settings_dialog.stringdata0))
         return static_cast<void*>(this);
     return QDialog::qt_metacast(_clname);
 }
 
-int settings_dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
+int octave::settings_dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = QDialog::qt_metacall(_c, _id, _a);
     if (_id < 0)
@@ -169,7 +169,7 @@ int settings_dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 }
 
 // SIGNAL 0
-void settings_dialog::apply_new_settings()
+void octave::settings_dialog::apply_new_settings()
 {
     QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
 }
