@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-4.4.1-1.x86_64/src/octave-4.4.1/libgui/src/variable-editor.h"
+#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/variable-editor.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__variable_dock_widget_t {
-    QByteArrayData data[12];
-    char stringdata0[163];
+    QByteArrayData data[16];
+    char stringdata0[217];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -38,21 +38,27 @@ QT_MOC_LITERAL(0, 0, 28), // "octave::variable_dock_widget"
 QT_MOC_LITERAL(1, 29, 23), // "variable_focused_signal"
 QT_MOC_LITERAL(2, 53, 0), // ""
 QT_MOC_LITERAL(3, 54, 4), // "name"
-QT_MOC_LITERAL(4, 59, 19), // "handle_focus_change"
-QT_MOC_LITERAL(5, 79, 8), // "QWidget*"
-QT_MOC_LITERAL(6, 88, 3), // "old"
-QT_MOC_LITERAL(7, 92, 3), // "now"
-QT_MOC_LITERAL(8, 96, 15), // "change_floating"
-QT_MOC_LITERAL(9, 112, 16), // "change_existence"
-QT_MOC_LITERAL(10, 129, 15), // "toplevel_change"
-QT_MOC_LITERAL(11, 145, 17) // "change_fullscreen"
+QT_MOC_LITERAL(4, 59, 19), // "queue_unfloat_float"
+QT_MOC_LITERAL(5, 79, 11), // "queue_float"
+QT_MOC_LITERAL(6, 91, 19), // "handle_focus_change"
+QT_MOC_LITERAL(7, 111, 8), // "QWidget*"
+QT_MOC_LITERAL(8, 120, 3), // "old"
+QT_MOC_LITERAL(9, 124, 3), // "now"
+QT_MOC_LITERAL(10, 128, 15), // "change_floating"
+QT_MOC_LITERAL(11, 144, 16), // "change_existence"
+QT_MOC_LITERAL(12, 161, 15), // "toplevel_change"
+QT_MOC_LITERAL(13, 177, 17), // "change_fullscreen"
+QT_MOC_LITERAL(14, 195, 13), // "unfloat_float"
+QT_MOC_LITERAL(15, 209, 7) // "refloat"
 
     },
     "octave::variable_dock_widget\0"
     "variable_focused_signal\0\0name\0"
+    "queue_unfloat_float\0queue_float\0"
     "handle_focus_change\0QWidget*\0old\0now\0"
     "change_floating\0change_existence\0"
-    "toplevel_change\0change_fullscreen"
+    "toplevel_change\0change_fullscreen\0"
+    "unfloat_float\0refloat"
 };
 #undef QT_MOC_LITERAL
 
@@ -62,31 +68,39 @@ static const uint qt_meta_data_octave__variable_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       6,   14, // methods
+      10,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       1,       // signalCount
+       3,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,   44,    2, 0x06 /* Public */,
+       1,    1,   64,    2, 0x06 /* Public */,
+       4,    0,   67,    2, 0x06 /* Public */,
+       5,    0,   68,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       4,    2,   47,    2, 0x0a /* Public */,
-       8,    1,   52,    2, 0x08 /* Private */,
-       9,    1,   55,    2, 0x08 /* Private */,
-      10,    1,   58,    2, 0x08 /* Private */,
-      11,    0,   61,    2, 0x08 /* Private */,
+       6,    2,   69,    2, 0x0a /* Public */,
+      10,    1,   74,    2, 0x08 /* Private */,
+      11,    1,   77,    2, 0x08 /* Private */,
+      12,    1,   80,    2, 0x08 /* Private */,
+      13,    0,   83,    2, 0x08 /* Private */,
+      14,    0,   84,    2, 0x09 /* Protected */,
+      15,    0,   85,    2, 0x09 /* Protected */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
+    QMetaType::Void,
+    QMetaType::Void,
 
  // slots: parameters
-    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,    6,    7,
+    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    9,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void,
+    QMetaType::Void,
     QMetaType::Void,
 
        0        // eod
@@ -99,11 +113,15 @@ void octave::variable_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::
         Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->variable_focused_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 1: _t->handle_focus_change((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
-        case 2: _t->change_floating((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 3: _t->change_existence((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 4: _t->toplevel_change((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 5: _t->change_fullscreen(); break;
+        case 1: _t->queue_unfloat_float(); break;
+        case 2: _t->queue_float(); break;
+        case 3: _t->handle_focus_change((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
+        case 4: _t->change_floating((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 5: _t->change_existence((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 6: _t->toplevel_change((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 7: _t->change_fullscreen(); break;
+        case 8: _t->unfloat_float(); break;
+        case 9: _t->refloat(); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -115,6 +133,20 @@ void octave::variable_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::
                 return;
             }
         }
+        {
+            typedef void (variable_dock_widget::*_t)();
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_dock_widget::queue_unfloat_float)) {
+                *result = 1;
+                return;
+            }
+        }
+        {
+            typedef void (variable_dock_widget::*_t)();
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_dock_widget::queue_float)) {
+                *result = 2;
+                return;
+            }
+        }
     }
 }
 
@@ -143,13 +175,13 @@ int octave::variable_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, voi
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 6)
+        if (_id < 10)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 6;
+        _id -= 10;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 6)
+        if (_id < 10)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 6;
+        _id -= 10;
     }
     return _id;
 }
@@ -160,6 +192,18 @@ void octave::variable_dock_widget::variable_focused_signal(const QString & _t1)
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 0, _a);
 }
+
+// SIGNAL 1
+void octave::variable_dock_widget::queue_unfloat_float()
+{
+    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
+}
+
+// SIGNAL 2
+void octave::variable_dock_widget::queue_float()
+{
+    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
+}
 struct qt_meta_stringdata_octave__variable_editor_stack_t {
     QByteArrayData data[12];
     char stringdata0[128];
@@ -308,8 +352,8 @@ void octave::variable_editor_stack::edit_variable_signal(const QString & _t1, co
     QMetaObject::activate(this, &staticMetaObject, 1, _a);
 }
 struct qt_meta_stringdata_octave__variable_editor_view_t {
-    QByteArrayData data[27];
-    char stringdata0[418];
+    QByteArrayData data[26];
+    char stringdata0[398];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -335,16 +379,15 @@ QT_MOC_LITERAL(13, 176, 12), // "clearContent"
 QT_MOC_LITERAL(14, 189, 12), // "cutClipboard"
 QT_MOC_LITERAL(15, 202, 13), // "copyClipboard"
 QT_MOC_LITERAL(16, 216, 14), // "pasteClipboard"
-QT_MOC_LITERAL(17, 231, 19), // "pasteTableClipboard"
-QT_MOC_LITERAL(18, 251, 31), // "handle_horizontal_scroll_action"
-QT_MOC_LITERAL(19, 283, 6), // "action"
-QT_MOC_LITERAL(20, 290, 29), // "handle_vertical_scroll_action"
-QT_MOC_LITERAL(21, 320, 17), // "createContextMenu"
-QT_MOC_LITERAL(22, 338, 2), // "pt"
-QT_MOC_LITERAL(23, 341, 16), // "createColumnMenu"
-QT_MOC_LITERAL(24, 358, 13), // "createRowMenu"
-QT_MOC_LITERAL(25, 372, 18), // "selected_to_octave"
-QT_MOC_LITERAL(26, 391, 26) // "selected_command_requested"
+QT_MOC_LITERAL(17, 231, 31), // "handle_horizontal_scroll_action"
+QT_MOC_LITERAL(18, 263, 6), // "action"
+QT_MOC_LITERAL(19, 270, 29), // "handle_vertical_scroll_action"
+QT_MOC_LITERAL(20, 300, 17), // "createContextMenu"
+QT_MOC_LITERAL(21, 318, 2), // "pt"
+QT_MOC_LITERAL(22, 321, 16), // "createColumnMenu"
+QT_MOC_LITERAL(23, 338, 13), // "createRowMenu"
+QT_MOC_LITERAL(24, 352, 18), // "selected_to_octave"
+QT_MOC_LITERAL(25, 371, 26) // "selected_command_requested"
 
     },
     "octave::variable_editor_view\0"
@@ -353,9 +396,8 @@ QT_MOC_LITERAL(26, 391, 26) // "selected_command_requested"
     "createVariable\0transposeContent\0"
     "range_selected\0QList<int>\0delete_selected\0"
     "clearContent\0cutClipboard\0copyClipboard\0"
-    "pasteClipboard\0pasteTableClipboard\0"
-    "handle_horizontal_scroll_action\0action\0"
-    "handle_vertical_scroll_action\0"
+    "pasteClipboard\0handle_horizontal_scroll_action\0"
+    "action\0handle_vertical_scroll_action\0"
     "createContextMenu\0pt\0createColumnMenu\0"
     "createRowMenu\0selected_to_octave\0"
     "selected_command_requested"
@@ -368,7 +410,7 @@ static const uint qt_meta_data_octave__variable_editor_view[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      18,   14, // methods
+      17,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -376,26 +418,25 @@ static const uint qt_meta_data_octave__variable_editor_view[] = {
        2,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  104,    2, 0x06 /* Public */,
-       4,    2,  107,    2, 0x06 /* Public */,
+       1,    1,   99,    2, 0x06 /* Public */,
+       4,    2,  102,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       8,    0,  112,    2, 0x0a /* Public */,
-       9,    0,  113,    2, 0x0a /* Public */,
-      10,    0,  114,    2, 0x0a /* Public */,
-      12,    0,  115,    2, 0x0a /* Public */,
-      13,    0,  116,    2, 0x0a /* Public */,
-      14,    0,  117,    2, 0x0a /* Public */,
-      15,    0,  118,    2, 0x0a /* Public */,
-      16,    0,  119,    2, 0x0a /* Public */,
-      17,    0,  120,    2, 0x0a /* Public */,
-      18,    1,  121,    2, 0x0a /* Public */,
-      20,    1,  124,    2, 0x0a /* Public */,
-      21,    1,  127,    2, 0x0a /* Public */,
-      23,    1,  130,    2, 0x0a /* Public */,
-      24,    1,  133,    2, 0x0a /* Public */,
-      25,    0,  136,    2, 0x0a /* Public */,
-      26,    1,  137,    2, 0x0a /* Public */,
+       8,    0,  107,    2, 0x0a /* Public */,
+       9,    0,  108,    2, 0x0a /* Public */,
+      10,    0,  109,    2, 0x0a /* Public */,
+      12,    0,  110,    2, 0x0a /* Public */,
+      13,    0,  111,    2, 0x0a /* Public */,
+      14,    0,  112,    2, 0x0a /* Public */,
+      15,    0,  113,    2, 0x0a /* Public */,
+      16,    0,  114,    2, 0x0a /* Public */,
+      17,    1,  115,    2, 0x0a /* Public */,
+      19,    1,  118,    2, 0x0a /* Public */,
+      20,    1,  121,    2, 0x0a /* Public */,
+      22,    1,  124,    2, 0x0a /* Public */,
+      23,    1,  127,    2, 0x0a /* Public */,
+      24,    0,  130,    2, 0x0a /* Public */,
+      25,    1,  131,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
@@ -410,12 +451,11 @@ static const uint qt_meta_data_octave__variable_editor_view[] = {
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void,
-    QMetaType::Void, QMetaType::Int,   19,
-    QMetaType::Void, QMetaType::Int,   19,
-    QMetaType::Void, QMetaType::QPoint,   22,
-    QMetaType::Void, QMetaType::QPoint,   22,
-    QMetaType::Void, QMetaType::QPoint,   22,
+    QMetaType::Void, QMetaType::Int,   18,
+    QMetaType::Void, QMetaType::Int,   18,
+    QMetaType::Void, QMetaType::QPoint,   21,
+    QMetaType::Void, QMetaType::QPoint,   21,
+    QMetaType::Void, QMetaType::QPoint,   21,
     QMetaType::QString,
     QMetaType::Void, QMetaType::QString,    3,
 
@@ -439,15 +479,14 @@ void octave::variable_editor_view::qt_static_metacall(QObject *_o, QMetaObject::
         case 7: _t->cutClipboard(); break;
         case 8: _t->copyClipboard(); break;
         case 9: _t->pasteClipboard(); break;
-        case 10: _t->pasteTableClipboard(); break;
-        case 11: _t->handle_horizontal_scroll_action((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 12: _t->handle_vertical_scroll_action((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 13: _t->createContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 14: _t->createColumnMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 15: _t->createRowMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 16: { QString _r = _t->selected_to_octave();
+        case 10: _t->handle_horizontal_scroll_action((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 11: _t->handle_vertical_scroll_action((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 12: _t->createContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 13: _t->createColumnMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 14: _t->createRowMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 15: { QString _r = _t->selected_to_octave();
             if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
-        case 17: _t->selected_command_requested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 16: _t->selected_command_requested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -494,13 +533,13 @@ int octave::variable_editor_view::qt_metacall(QMetaObject::Call _c, int _id, voi
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 18)
+        if (_id < 17)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 18;
+        _id -= 17;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 18)
+        if (_id < 17)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 18;
+        _id -= 17;
     }
     return _id;
 }
@@ -854,8 +893,8 @@ void octave::ReturnFocusMenu::about_to_activate()
     QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
 }
 struct qt_meta_stringdata_octave__variable_editor_t {
-    QByteArrayData data[36];
-    char stringdata0[549];
+    QByteArrayData data[34];
+    char stringdata0[500];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -874,49 +913,45 @@ QT_MOC_LITERAL(6, 61, 14), // "refresh_signal"
 QT_MOC_LITERAL(7, 76, 20), // "clear_content_signal"
 QT_MOC_LITERAL(8, 97, 21), // "copy_clipboard_signal"
 QT_MOC_LITERAL(9, 119, 22), // "paste_clipboard_signal"
-QT_MOC_LITERAL(10, 142, 28), // "paste_table_clipboard_signal"
-QT_MOC_LITERAL(11, 171, 15), // "level_up_signal"
-QT_MOC_LITERAL(12, 187, 11), // "save_signal"
-QT_MOC_LITERAL(13, 199, 22), // "delete_selected_signal"
-QT_MOC_LITERAL(14, 222, 23), // "selected_command_signal"
-QT_MOC_LITERAL(15, 246, 10), // "callUpdate"
-QT_MOC_LITERAL(16, 257, 15), // "notice_settings"
-QT_MOC_LITERAL(17, 273, 16), // "const QSettings*"
-QT_MOC_LITERAL(18, 290, 13), // "edit_variable"
-QT_MOC_LITERAL(19, 304, 4), // "name"
-QT_MOC_LITERAL(20, 309, 12), // "octave_value"
-QT_MOC_LITERAL(21, 322, 3), // "val"
-QT_MOC_LITERAL(22, 326, 18), // "variable_destroyed"
-QT_MOC_LITERAL(23, 345, 3), // "obj"
-QT_MOC_LITERAL(24, 349, 16), // "variable_focused"
-QT_MOC_LITERAL(25, 366, 29), // "record_hovered_focus_variable"
-QT_MOC_LITERAL(26, 396, 30), // "restore_hovered_focus_variable"
-QT_MOC_LITERAL(27, 427, 10), // "closeEvent"
-QT_MOC_LITERAL(28, 438, 12), // "QCloseEvent*"
-QT_MOC_LITERAL(29, 451, 4), // "save"
-QT_MOC_LITERAL(30, 456, 12), // "cutClipboard"
-QT_MOC_LITERAL(31, 469, 13), // "copyClipboard"
-QT_MOC_LITERAL(32, 483, 14), // "pasteClipboard"
-QT_MOC_LITERAL(33, 498, 19), // "pasteTableClipboard"
-QT_MOC_LITERAL(34, 518, 7), // "levelUp"
-QT_MOC_LITERAL(35, 526, 22) // "relay_selected_command"
+QT_MOC_LITERAL(10, 142, 15), // "level_up_signal"
+QT_MOC_LITERAL(11, 158, 11), // "save_signal"
+QT_MOC_LITERAL(12, 170, 22), // "delete_selected_signal"
+QT_MOC_LITERAL(13, 193, 23), // "selected_command_signal"
+QT_MOC_LITERAL(14, 217, 10), // "callUpdate"
+QT_MOC_LITERAL(15, 228, 15), // "notice_settings"
+QT_MOC_LITERAL(16, 244, 16), // "const QSettings*"
+QT_MOC_LITERAL(17, 261, 13), // "edit_variable"
+QT_MOC_LITERAL(18, 275, 4), // "name"
+QT_MOC_LITERAL(19, 280, 12), // "octave_value"
+QT_MOC_LITERAL(20, 293, 3), // "val"
+QT_MOC_LITERAL(21, 297, 18), // "variable_destroyed"
+QT_MOC_LITERAL(22, 316, 3), // "obj"
+QT_MOC_LITERAL(23, 320, 16), // "variable_focused"
+QT_MOC_LITERAL(24, 337, 29), // "record_hovered_focus_variable"
+QT_MOC_LITERAL(25, 367, 30), // "restore_hovered_focus_variable"
+QT_MOC_LITERAL(26, 398, 10), // "closeEvent"
+QT_MOC_LITERAL(27, 409, 12), // "QCloseEvent*"
+QT_MOC_LITERAL(28, 422, 4), // "save"
+QT_MOC_LITERAL(29, 427, 12), // "cutClipboard"
+QT_MOC_LITERAL(30, 440, 13), // "copyClipboard"
+QT_MOC_LITERAL(31, 454, 14), // "pasteClipboard"
+QT_MOC_LITERAL(32, 469, 7), // "levelUp"
+QT_MOC_LITERAL(33, 477, 22) // "relay_selected_command"
 
     },
     "octave::variable_editor\0updated\0\0"
     "finished\0command_signal\0cmd\0refresh_signal\0"
     "clear_content_signal\0copy_clipboard_signal\0"
-    "paste_clipboard_signal\0"
-    "paste_table_clipboard_signal\0"
-    "level_up_signal\0save_signal\0"
-    "delete_selected_signal\0selected_command_signal\0"
-    "callUpdate\0notice_settings\0const QSettings*\0"
+    "paste_clipboard_signal\0level_up_signal\0"
+    "save_signal\0delete_selected_signal\0"
+    "selected_command_signal\0callUpdate\0"
+    "notice_settings\0const QSettings*\0"
     "edit_variable\0name\0octave_value\0val\0"
     "variable_destroyed\0obj\0variable_focused\0"
     "record_hovered_focus_variable\0"
     "restore_hovered_focus_variable\0"
     "closeEvent\0QCloseEvent*\0save\0cutClipboard\0"
-    "copyClipboard\0pasteClipboard\0"
-    "pasteTableClipboard\0levelUp\0"
+    "copyClipboard\0pasteClipboard\0levelUp\0"
     "relay_selected_command"
 };
 #undef QT_MOC_LITERAL
@@ -927,43 +962,41 @@ static const uint qt_meta_data_octave__variable_editor[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      27,   14, // methods
+      25,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-      12,       // signalCount
+      11,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    0,  149,    2, 0x06 /* Public */,
-       3,    0,  150,    2, 0x06 /* Public */,
-       4,    1,  151,    2, 0x06 /* Public */,
-       6,    0,  154,    2, 0x06 /* Public */,
-       7,    0,  155,    2, 0x06 /* Public */,
-       8,    0,  156,    2, 0x06 /* Public */,
-       9,    0,  157,    2, 0x06 /* Public */,
-      10,    0,  158,    2, 0x06 /* Public */,
-      11,    0,  159,    2, 0x06 /* Public */,
-      12,    0,  160,    2, 0x06 /* Public */,
-      13,    0,  161,    2, 0x06 /* Public */,
-      14,    1,  162,    2, 0x06 /* Public */,
+       1,    0,  139,    2, 0x06 /* Public */,
+       3,    0,  140,    2, 0x06 /* Public */,
+       4,    1,  141,    2, 0x06 /* Public */,
+       6,    0,  144,    2, 0x06 /* Public */,
+       7,    0,  145,    2, 0x06 /* Public */,
+       8,    0,  146,    2, 0x06 /* Public */,
+       9,    0,  147,    2, 0x06 /* Public */,
+      10,    0,  148,    2, 0x06 /* Public */,
+      11,    0,  149,    2, 0x06 /* Public */,
+      12,    0,  150,    2, 0x06 /* Public */,
+      13,    1,  151,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      15,    2,  165,    2, 0x0a /* Public */,
-      16,    1,  170,    2, 0x0a /* Public */,
-      18,    2,  173,    2, 0x0a /* Public */,
-      22,    1,  178,    2, 0x0a /* Public */,
-      24,    1,  181,    2, 0x0a /* Public */,
-      25,    0,  184,    2, 0x0a /* Public */,
-      26,    0,  185,    2, 0x0a /* Public */,
-      27,    1,  186,    2, 0x09 /* Protected */,
-      29,    0,  189,    2, 0x09 /* Protected */,
-      30,    0,  190,    2, 0x09 /* Protected */,
-      31,    0,  191,    2, 0x09 /* Protected */,
-      32,    0,  192,    2, 0x09 /* Protected */,
-      33,    0,  193,    2, 0x09 /* Protected */,
-      34,    0,  194,    2, 0x09 /* Protected */,
-      35,    1,  195,    2, 0x09 /* Protected */,
+      14,    2,  154,    2, 0x0a /* Public */,
+      15,    1,  159,    2, 0x0a /* Public */,
+      17,    2,  162,    2, 0x0a /* Public */,
+      21,    1,  167,    2, 0x0a /* Public */,
+      23,    1,  170,    2, 0x0a /* Public */,
+      24,    0,  173,    2, 0x0a /* Public */,
+      25,    0,  174,    2, 0x0a /* Public */,
+      26,    1,  175,    2, 0x09 /* Protected */,
+      28,    0,  178,    2, 0x09 /* Protected */,
+      29,    0,  179,    2, 0x09 /* Protected */,
+      30,    0,  180,    2, 0x09 /* Protected */,
+      31,    0,  181,    2, 0x09 /* Protected */,
+      32,    0,  182,    2, 0x09 /* Protected */,
+      33,    1,  183,    2, 0x09 /* Protected */,
 
  // signals: parameters
     QMetaType::Void,
@@ -976,19 +1009,17 @@ static const uint qt_meta_data_octave__variable_editor[] = {
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void,
     QMetaType::Void, QMetaType::QString,    5,
 
  // slots: parameters
     QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    2,    2,
-    QMetaType::Void, 0x80000000 | 17,    2,
-    QMetaType::Void, QMetaType::QString, 0x80000000 | 20,   19,   21,
-    QMetaType::Void, QMetaType::QObjectStar,   23,
-    QMetaType::Void, QMetaType::QString,   19,
+    QMetaType::Void, 0x80000000 | 16,    2,
+    QMetaType::Void, QMetaType::QString, 0x80000000 | 19,   18,   20,
+    QMetaType::Void, QMetaType::QObjectStar,   22,
+    QMetaType::Void, QMetaType::QString,   18,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 28,    2,
-    QMetaType::Void,
+    QMetaType::Void, 0x80000000 | 27,    2,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -1012,26 +1043,24 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 4: _t->clear_content_signal(); break;
         case 5: _t->copy_clipboard_signal(); break;
         case 6: _t->paste_clipboard_signal(); break;
-        case 7: _t->paste_table_clipboard_signal(); break;
-        case 8: _t->level_up_signal(); break;
-        case 9: _t->save_signal(); break;
-        case 10: _t->delete_selected_signal(); break;
-        case 11: _t->selected_command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 12: _t->callUpdate((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
-        case 13: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 14: _t->edit_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
-        case 15: _t->variable_destroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
-        case 16: _t->variable_focused((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 17: _t->record_hovered_focus_variable(); break;
-        case 18: _t->restore_hovered_focus_variable(); break;
-        case 19: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
-        case 20: _t->save(); break;
-        case 21: _t->cutClipboard(); break;
-        case 22: _t->copyClipboard(); break;
-        case 23: _t->pasteClipboard(); break;
-        case 24: _t->pasteTableClipboard(); break;
-        case 25: _t->levelUp(); break;
-        case 26: _t->relay_selected_command((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 7: _t->level_up_signal(); break;
+        case 8: _t->save_signal(); break;
+        case 9: _t->delete_selected_signal(); break;
+        case 10: _t->selected_command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 11: _t->callUpdate((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
+        case 12: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
+        case 13: _t->edit_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
+        case 14: _t->variable_destroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
+        case 15: _t->variable_focused((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 16: _t->record_hovered_focus_variable(); break;
+        case 17: _t->restore_hovered_focus_variable(); break;
+        case 18: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
+        case 19: _t->save(); break;
+        case 20: _t->cutClipboard(); break;
+        case 21: _t->copyClipboard(); break;
+        case 22: _t->pasteClipboard(); break;
+        case 23: _t->levelUp(); break;
+        case 24: _t->relay_selected_command((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -1087,36 +1116,29 @@ void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call
         }
         {
             typedef void (variable_editor::*_t)();
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::paste_table_clipboard_signal)) {
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::level_up_signal)) {
                 *result = 7;
                 return;
             }
         }
         {
             typedef void (variable_editor::*_t)();
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::level_up_signal)) {
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::save_signal)) {
                 *result = 8;
                 return;
             }
         }
-        {
-            typedef void (variable_editor::*_t)();
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::save_signal)) {
-                *result = 9;
-                return;
-            }
-        }
         {
             typedef void (variable_editor::*_t)();
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::delete_selected_signal)) {
-                *result = 10;
+                *result = 9;
                 return;
             }
         }
         {
             typedef void (variable_editor::*_t)(const QString & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::selected_command_signal)) {
-                *result = 11;
+                *result = 10;
                 return;
             }
         }
@@ -1148,13 +1170,13 @@ int octave::variable_editor::qt_metacall(QMetaObject::Call _c, int _id, void **_
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 27)
+        if (_id < 25)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 27;
+        _id -= 25;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 27)
+        if (_id < 25)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 27;
+        _id -= 25;
     }
     return _id;
 }
@@ -1203,34 +1225,28 @@ void octave::variable_editor::paste_clipboard_signal()
 }
 
 // SIGNAL 7
-void octave::variable_editor::paste_table_clipboard_signal()
+void octave::variable_editor::level_up_signal()
 {
     QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
 }
 
 // SIGNAL 8
-void octave::variable_editor::level_up_signal()
+void octave::variable_editor::save_signal()
 {
     QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
 }
 
 // SIGNAL 9
-void octave::variable_editor::save_signal()
+void octave::variable_editor::delete_selected_signal()
 {
     QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
 }
 
 // SIGNAL 10
-void octave::variable_editor::delete_selected_signal()
-{
-    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
-}
-
-// SIGNAL 11
 void octave::variable_editor::selected_command_signal(const QString & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
-    QMetaObject::activate(this, &staticMetaObject, 11, _a);
+    QMetaObject::activate(this, &staticMetaObject, 10, _a);
 }
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
